@@ -1,6 +1,6 @@
 see.unif.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     minX <- 2.5
@@ -32,7 +32,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Uniform Distribution")
+    tkwm.title(m, "UNIF(a, b)")
     tkpack(tklabel(m,text="      Visualizing the Uniform Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
@@ -71,7 +71,7 @@ require(tcltk) || stop("tcltk support is absent")
 
 see.unifcdf.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     minX <- 2.5
@@ -84,7 +84,7 @@ require(tcltk) || stop("tcltk support is absent")
     assign("xmax", tclVar(xmax), envir = slider.env)
      
     
-    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
     norm.refresh <- function(...) {
         minX <- as.numeric(evalq(tclvalue(minX), envir = slider.env))
         maxX <- as.numeric(evalq(tclvalue(maxX), envir = slider.env))
@@ -105,7 +105,7 @@ require(tcltk) || stop("tcltk support is absent")
             }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Uniform Distribution")
+     tkwm.title(m, "UNIF(a, b)")
     tkpack(tklabel(m,text="      Visualizing the Uniform Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
